pub fn parse_one_blame(porcelain: &[&str]) -> Result<Blame, ParseError>Expand description
Parses the porcelain format output corresponding to a single line to construct a Blame object.
pub fn parse_one_blame(porcelain: &[&str]) -> Result<Blame, ParseError>Parses the porcelain format output corresponding to a single line to construct a Blame object.